@@ -1,6 +1,10 @@
 """Exec module for managing Subnetworks."""
 __func_alias__ = {"list_": "list"}
 
+from typing import Any, Dict, List
+
+from idem_gcp.tool.gcp.generate.exec_context import ExecutionContext
+
 
 async def list_(
     hub,
@@ -134,3 +138,58 @@ async def get(
 
     result["ret"] = ret["ret"]
     return result
+
+
+async def update_ip_cidr_range(
+    hub,
+    ctx,
+    new_ip_cidr_range: List[Dict[str, Any]],
+    project: str = None,
+    region: str = None,
+    subnetwork: str = None,
+    resource_id: str = None,
+    request_id: str = None,
+):
+    r"""Expands the IP CIDR range of the subnetwork to a specified value.
+
+    Args:
+        new_ip_cidr_range: The IP (in CIDR format or netmask) of internal addresses that are legal on
+        this Subnetwork. This range should be disjoint from other subnetworks within this network.
+        This range can only be larger than (i.e. a superset of) the range previously defined before the update.
+
+        project(str, Optional):
+            Project ID for this request.
+
+        region(str, Optional):
+            Name of the region scoping this request.
+
+        subnetwork(str, Optional):
+            Name of the Subnetwork resource to update.
+
+        resource_id(str, Optional):
+            An identifier of the resource in the provider.
+
+        request_id(str, Optional): An optional request ID to identify requests. Specify a unique request ID so that
+        if you must retry your request, the server will know to ignore the request if it has already been completed.
+        For example, consider a situation where you make an initial request and the request times out. If you make
+        the request again with the same request ID, the server can check if original operation with the same request
+        ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating
+        duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported
+        (00000000-0000-0000-0000-000000000000).
+    """
+    request_body = {"ip_cidr_range": new_ip_cidr_range}
+    project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
+    execution_context = ExecutionContext(
+        resource_type="compute.subnetwork",
+        method_name="expandIpCidrRange",
+        method_params={
+            "ctx": ctx,
+            "resource_id": resource_id,
+            "request_id": request_id,
+            "project": project,
+            "region": region,
+            "subnetwork": subnetwork,
+            "body": request_body,
+        },
+    )
+    return await hub.tool.gcp.generate.generic_exec.execute(execution_context)
