@@ -1,10 +1,10 @@
 """State module for managing Cloud Key Management Service crypto keys."""
+import copy
 from copy import deepcopy
 from dataclasses import field
 from dataclasses import make_dataclass
 from typing import Any
 from typing import Dict
-from typing import List
 
 __contracts__ = ["resource"]
 
@@ -19,34 +19,8 @@ async def present(
     key_ring_id: str = None,
     crypto_key_id: str = None,
     key_state: str = None,
-    protection_level: str = None,
     algorithm: str = None,
-    attestation: make_dataclass(
-        "KeyOperationAttestation",
-        [
-            ("format", str, field(default=None)),
-            ("content", str, field(default=None)),
-            (
-                "cert_chains",
-                make_dataclass(
-                    "CertificateChains",
-                    [
-                        ("cavium_certs", List[str], field(default=None)),
-                        ("google_card_certs", List[str], field(default=None)),
-                        ("google_partition_certs", List[str], field(default=None)),
-                    ],
-                ),
-                field(default=None),
-            ),
-        ],
-    ) = None,
-    create_time: str = None,
-    generate_time: str = None,
-    destroy_time: str = None,
-    destroy_event_time: str = None,
     import_job: str = None,
-    import_time: str = None,
-    import_failure_reason: str = None,
     external_protection_level_options: make_dataclass(
         "ExternalProtectionLevelOptions",
         [
@@ -54,7 +28,6 @@ async def present(
             ("ekm_connection_key_path", str, field(default=None)),
         ],
     ) = None,
-    reimport_eligible: bool = None,
     resource_id: str = None,
     key_material: str = None,
 ) -> Dict[str, Any]:
@@ -82,39 +55,9 @@ async def present(
         key_state(str, Optional):
             The current state of the `CryptoKeyVersion`_.
 
-        protection_level(str, Optional):
-            Output only. The `ProtectionLevel`_ describing how crypto operations are performed with this `CryptoKeyVersion`_.
-
         algorithm(str, Optional):
             Output only. The `CryptoKeyVersionAlgorithm`_ that this `CryptoKeyVersion`_ supports.
 
-        attestation(Dict[str, Any], Optional):
-            Output only. Statement that was generated and signed by the HSM at key creation time. Use this statement to
-            verify attributes of the key as stored on the HSM, independently of Google. Only provided for key versions
-            with `protectionLevel`_ `HSM`_.
-
-        create_time(str, Optional):
-            Output only. The time at which this `CryptoKeyVersion`_ was created.
-
-            A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits.
-            Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
-
-        generate_time(str, Optional):
-            Output only. The time this `CryptoKeyVersion`_'s key material was generated.
-
-            A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits.
-            Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
-
-        destroy_time(str, Optional):
-            Output only. The time this `CryptoKeyVersion`_'s key material is scheduled for destruction. Only present if
-            `state`_ is `DESTROY_SCHEDULED`_.
-
-            A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits.
-            Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
-
-        destroy_event_time(str, Optional):
-            Output only. The time this `CryptoKeyVersion`_'s key material was destroyed. Only present if `state`_ is `DESTROYED`_.
-
             A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits.
             Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
 
@@ -122,23 +65,6 @@ async def present(
             Output only. The name of the `ImportJob`_ used in the most recent import of this `CryptoKeyVersion`_. Only
             present if the underlying key material was imported.
 
-        import_time(str, Optional):
-            Output only. The time at which this `CryptoKeyVersion`_'s key material was most recently imported.
-
-            A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits.
-            Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
-
-        import_failure_reason(str, Optional):
-            Output only. The root cause of the most recent import failure. Only present if state is `IMPORT_FAILED`_.
-
-        external_protection_level_options(Dict[str, Any], Optional):
-            `ExternalProtectionLevelOptions`_ stores a group of additional fields for configuring a `CryptoKeyVersion`_
-             that are specific to the `EXTERNAL`_ protection level and `EXTERNAL_VPC`_ protection levels.
-
-        reimport_eligible(bool, Optional):
-            Output only. Whether or not this key version is eligible for reimport, by being specified as a target in
-            `ImportCryptoKeyVersionRequest.crypto_key_version`_.
-
         resource_id(str, Optional): Idem resource id. Formatted as
 
             `projects/{project_id}/locations/{location_id}/keyRings/{key_ring_id}/cryptoKeys/{crypto_key_id}/cryptoKeyVersions/{crypto_key_version_id}`
@@ -203,29 +129,21 @@ async def present(
         "comment": [],
     }
 
-    create_if_missing = False
-    if not resource_id:
-        if project_id and location_id and key_ring_id and crypto_key_id:
-            if crypto_key_version_id:
-                resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-                    "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
-                    {
-                        "project_id": project_id,
-                        "location_id": location_id,
-                        "key_ring_id": key_ring_id,
-                        "crypto_key_id": crypto_key_id,
-                        "crypto_key_version_id": crypto_key_version_id,
-                    },
-                )
-            else:
-                create_if_missing = True
-        else:
+    get_resource_only_with_resource_id = hub.OPT.idem.get(
+        "get_resource_only_with_resource_id", False
+    )
+    if resource_id:
+        old_get_ret = await hub.exec.gcp.cloudkms.crypto_key_version.get(
+            ctx, resource_id=resource_id
+        )
+
+        if not old_get_ret["result"] or (
+            not old_get_ret["ret"] and get_resource_only_with_resource_id
+        ):
             result["result"] = False
-            result["comment"].append(
-                "When creating new resource crypto_key_version_id, project_id, location_id, key_ring_id and crypto_key_id parameters are required!"
-            )
+            result["comment"] += old_get_ret["comment"]
             return result
-    else:
+
         els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
             "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
             resource_id,
@@ -266,39 +184,39 @@ async def present(
             crypto_key_id = els.get("crypto_key_id")
             crypto_key_version_id = els.get("crypto_key_version_id")
 
-    is_create = False
-    if resource_id:
+        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+    elif not get_resource_only_with_resource_id:
+        if project_id and location_id and key_ring_id and crypto_key_id:
+            if crypto_key_version_id:
+                resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
+                    "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
+                    {
+                        "project_id": project_id,
+                        "location_id": location_id,
+                        "key_ring_id": key_ring_id,
+                        "crypto_key_id": crypto_key_id,
+                        "crypto_key_version_id": crypto_key_version_id,
+                    },
+                )
+        else:
+            result["result"] = False
+            result["comment"].append(
+                "When creating new resource crypto_key_version_id, project_id, location_id, key_ring_id and "
+                "crypto_key_id parameters are required! "
+            )
+            return result
+
         old_get_ret = await hub.exec.gcp.cloudkms.crypto_key_version.get(
             ctx, resource_id=resource_id
         )
-        if not old_get_ret["result"] or not old_get_ret["ret"]:
-            if not create_if_missing:
-                result["result"] = False
-                result["comment"] += old_get_ret["comment"]
-                return result
-            is_create = True
-        else:
-            result["old_state"] = {
-                "name": name,
-                "project_id": project_id,
-                "location_id": location_id,
-                "key_ring_id": key_ring_id,
-                "crypto_key_id": crypto_key_id,
-                "crypto_key_version_id": crypto_key_version_id,
-                **hub.tool.gcp.cloudkms.crypto_key_version_utils.to_state(
-                    old_get_ret["ret"]
-                ),
-            }
-            if (
-                result["old_state"].get("key_state") != "PENDING_IMPORT"
-                and key_state == "PENDING_IMPORT"
-                and ctx.get("rerun_data")
-                and ctx.get("rerun_data").get("imported_key_material")
-            ):
-                key_state = result["old_state"].get("key_state")
 
-    else:
-        is_create = create_if_missing
+        if not old_get_ret["result"]:
+            result["result"] = False
+            result["comment"] += old_get_ret["comment"]
+            return result
+
+        if old_get_ret["ret"]:
+            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
 
     resource_body = {
         "state": key_state,
@@ -312,8 +230,8 @@ async def present(
             key_material is not None,
             algorithm is not None,
             import_job,
-            result["old_state"].get("key_state")
-            if not is_create and "old_state" in result
+            (result.get("old_state") or {}).get("key_state")
+            if "old_state" in result
             else None,
         )
     )
@@ -325,8 +243,18 @@ async def present(
         return result
 
     if ctx["test"]:
+        resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
+            "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
+            {
+                "project_id": project_id,
+                "location_id": location_id,
+                "key_ring_id": key_ring_id,
+                "crypto_key_id": crypto_key_id,
+                "crypto_key_version_id": crypto_key_version_id,
+            },
+        )
         if import_key_ret["ret"]:
-            if is_create:
+            if not result["old_state"]:
                 result["comment"] += (
                     "Key material will be imported in new gcp.cloudkms.crypto_key_version",
                 )
@@ -335,7 +263,7 @@ async def present(
                     f"Key material will be re-imported in gcp.cloudkms.crypto_key_version '{resource_id}'",
                 )
             return result
-        if is_create:
+        if not result["old_state"]:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.would_create_comment(
                     "gcp.cloudkms.crypto_key_version", resource_id
@@ -374,7 +302,7 @@ async def present(
                 )
             else:
                 result["comment"].append(
-                    hub.tool.gcp.comment_utils.already_exists_comment(
+                    hub.tool.gcp.comment_utils.up_to_date_comment(
                         "gcp.cloudkms.crypto_key_version", resource_id
                     )
                 )
@@ -417,21 +345,14 @@ async def present(
         }
         result["rerun_data"] = {"imported_key_material": True}
         result["comment"].append(
-            f"Key material {'imported' if is_create else 're-imported'} in gcp.cloudkms.crypto_key_version {result['new_state']['resource_id']}"
+            f"Key material {'imported' if not result['old_state'] else 're-imported'} in gcp.cloudkms"
+            f".crypto_key_version {result['new_state']['resource_id']} "
         )
         return result
 
-    if is_create:
-        create_ret = await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions.create(
-            ctx,
-            parent=parent,
-            body=resource_body,
-        )
-        if not create_ret["result"]:
-            result["result"] = False
-            result["comment"] += create_ret["comment"]
-            return result
-        result["new_state"] = {
+    if result["old_state"]:
+        resource_id = result["old_state"].get("resource_id", None)
+        result["old_state"] = {
             "name": name,
             "project_id": project_id,
             "location_id": location_id,
@@ -439,15 +360,17 @@ async def present(
             "crypto_key_id": crypto_key_id,
             "crypto_key_version_id": crypto_key_version_id,
             **hub.tool.gcp.cloudkms.crypto_key_version_utils.to_state(
-                create_ret["ret"]
+                old_get_ret["ret"]
             ),
         }
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.create_comment(
-                "gcp.cloudkms.crypto_key_version", result["new_state"]["resource_id"]
-            )
-        )
-    else:
+        if (
+            result["old_state"].get("key_state") != "PENDING_IMPORT"
+            and key_state == "PENDING_IMPORT"
+            and ctx.get("rerun_data")
+            and ctx.get("rerun_data").get("imported_key_material")
+        ):
+            key_state = result["old_state"].get("key_state")
+
         update_mask = hub.tool.gcp.cloudkms.patch.calc_update_mask(
             resource_body,
             {
@@ -494,11 +417,37 @@ async def present(
             }
         else:
             result["comment"].append(
-                hub.tool.gcp.comment_utils.already_exists_comment(
+                hub.tool.gcp.comment_utils.up_to_date_comment(
                     "gcp.cloudkms.crypto_key_version", resource_id
                 )
             )
-            result["new_state"] = deepcopy(result["old_state"])
+
+    else:
+        create_ret = await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions.create(
+            ctx,
+            parent=parent,
+            body=resource_body,
+        )
+        if not create_ret["result"]:
+            result["result"] = False
+            result["comment"] += create_ret["comment"]
+            return result
+        result["new_state"] = {
+            "name": name,
+            "project_id": project_id,
+            "location_id": location_id,
+            "key_ring_id": key_ring_id,
+            "crypto_key_id": crypto_key_id,
+            "crypto_key_version_id": crypto_key_version_id,
+            **hub.tool.gcp.cloudkms.crypto_key_version_utils.to_state(
+                create_ret["ret"]
+            ),
+        }
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.create_comment(
+                "gcp.cloudkms.crypto_key_version", result["new_state"]["resource_id"]
+            )
+        )
 
     return result
 
@@ -568,17 +517,13 @@ async def absent(
         "result": True,
     }
 
-    if not resource_id:
-        resource_id = (ctx.old_state or {}).get("resource_id")
-        if (
-            not resource_id
-            and project_id
-            and location_id
-            and key_ring_id
-            and crypto_key_id
-            and crypto_key_version_id
-        ):
-            resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
+    get_resource_only_with_resource_id = hub.OPT.idem.get(
+        "get_resource_only_with_resource_id", False
+    )
+
+    if not resource_id and not get_resource_only_with_resource_id:
+        resource_id = (
+            hub.tool.gcp.resource_prop_utils.construct_resource_id(
                 "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
                 {
                     "project_id": project_id,
@@ -588,10 +533,20 @@ async def absent(
                     "crypto_key_version_id": crypto_key_version_id,
                 },
             )
-        else:
-            result["result"] = False
-            result["comment"] += ["Can not determine resource_id."]
-            return result
+            if project_id
+            and location_id
+            and key_ring_id
+            and crypto_key_id
+            and crypto_key_version_id
+            else None
+        )
+
+    if not resource_id:
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.already_absent_comment("gcp.compute.disk", name)
+        )
+        result["result"] = False
+        return result
 
     if ctx.test:
         result["comment"].append(
