@@ -159,24 +159,46 @@ async def present(
         "comment": [],
     }
 
-    if not resource_id:
-        if project_id and location_id and key_ring_id and import_job_id:
-            resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-                "cloudkms.projects.locations.key_rings.import_jobs",
-                {
-                    "project_id": project_id,
-                    "location_id": location_id,
-                    "key_ring_id": key_ring_id,
-                    "import_job_id": import_job_id,
-                },
-            )
-        else:
+    get_resource_only_with_resource_id = hub.OPT.idem.get(
+        "get_resource_only_with_resource_id", False
+    )
+    if resource_id:
+        old_get_ret = await hub.exec.gcp.cloudkms.import_job.get(
+            ctx, resource_id=resource_id
+        )
+
+        if not old_get_ret["result"] or (
+            not old_get_ret["ret"] and get_resource_only_with_resource_id
+        ):
             result["result"] = False
-            result["comment"].append(
-                "When creating new resource crypto_key_id, project_id, location_id and key_ring_id parameters are required!"
-            )
+            result["comment"] += old_get_ret["comment"]
             return result
-    else:
+
+        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+    elif not get_resource_only_with_resource_id:
+        resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
+            "cloudkms.projects.locations.key_rings.import_jobs",
+            {
+                "project_id": project_id,
+                "location_id": location_id,
+                "key_ring_id": key_ring_id,
+                "import_job_id": import_job_id,
+            },
+        )
+        old_get_ret = await hub.exec.gcp.cloudkms.import_job.get(
+            ctx, resource_id=resource_id
+        )
+
+        if not old_get_ret["result"]:
+            result["result"] = False
+            result["comment"] += old_get_ret["comment"]
+            return result
+
+        if old_get_ret["ret"]:
+            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+
+    if result["old_state"]:
+        resource_id = result["old_state"].get("resource_id", None)
         els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
             "cloudkms.projects.locations.key_rings.import_jobs", resource_id
         )
@@ -196,30 +218,7 @@ async def present(
                     )
                 )
                 return result
-        else:
-            project_id = els.get("project_id")
-            location_id = els.get("location_id")
-            key_ring_id = els.get("key_ring_id")
-            import_job_id = els.get("import_job_id")
 
-    old_get_ret = await hub.exec.gcp.cloudkms.import_job.get(
-        ctx, resource_id=resource_id
-    )
-
-    if not old_get_ret["result"]:
-        result["result"] = False
-        result["comment"] += old_get_ret["comment"]
-        return result
-
-    if old_get_ret["ret"]:
-        result["old_state"] = {
-            "name": name,
-            "project_id": project_id,
-            "location_id": location_id,
-            "key_ring_id": key_ring_id,
-            "import_job_id": import_job_id,
-            **copy.copy(old_get_ret["ret"]),
-        }
         if (
             result["old_state"].get("import_method") != import_method
             or result["old_state"].get("protection_level") != protection_level
