@@ -406,11 +406,13 @@ async def present(
                             operation.get("selfLink"), "compute.zone_operation"
                         )
                     )
-                    op_ret = await hub.tool.gcp.operation_utils.handle_operation(
-                        ctx, operation_id, "compute.disk", True
+                    handle_operation_ret = (
+                        await hub.tool.gcp.operation_utils.handle_operation(
+                            ctx, {"operation_id": operation_id}, "compute.disk", True
+                        )
                     )
-                    if not op_ret["result"]:
-                        result["comment"] += op_ret["comment"]
+                    if not handle_operation_ret["result"]:
+                        result["comment"] += handle_operation_ret["comment"]
                         return result
 
             size_gb_updated = True
@@ -448,11 +450,13 @@ async def present(
                             operation.get("selfLink"), "compute.zone_operation"
                         )
                     )
-                    op_ret = await hub.tool.gcp.operation_utils.handle_operation(
-                        ctx, operation_id, "compute.disk", True
+                    handle_operation_ret = (
+                        await hub.tool.gcp.operation_utils.handle_operation(
+                            ctx, {"operation_id": operation_id}, "compute.disk", True
+                        )
                     )
-                    if not op_ret["result"]:
-                        result["comment"] += op_ret["comment"]
+                    if not handle_operation_ret["result"]:
+                        result["comment"] += handle_operation_ret["comment"]
                         return result
 
             labels_updated = True
@@ -524,13 +528,16 @@ async def present(
                             operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
                                 operation.get("selfLink"), "compute.zone_operation"
                             )
-                            op_ret = (
+                            handle_operation_ret = (
                                 await hub.tool.gcp.operation_utils.handle_operation(
-                                    ctx, operation_id, "compute.disk", True
+                                    ctx,
+                                    {"operation_id": operation_id},
+                                    "compute.disk",
+                                    True,
                                 )
                             )
-                            if not op_ret["result"]:
-                                result["comment"] += op_ret["comment"]
+                            if not handle_operation_ret["result"]:
+                                result["comment"] += handle_operation_ret["comment"]
                                 return result
 
                     if (
@@ -553,13 +560,16 @@ async def present(
                             operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
                                 operation.get("selfLink"), "compute.zone_operation"
                             )
-                            op_ret = (
+                            handle_operation_ret = (
                                 await hub.tool.gcp.operation_utils.handle_operation(
-                                    ctx, operation_id, "compute.disk", True
+                                    ctx,
+                                    {"operation_id": operation_id},
+                                    "compute.disk",
+                                    True,
                                 )
                             )
-                            if not op_ret["result"]:
-                                result["comment"] += op_ret["comment"]
+                            if not handle_operation_ret["result"]:
+                                result["comment"] += handle_operation_ret["comment"]
                                 return result
 
                 resource_policies_updated = True
