@@ -180,13 +180,18 @@ async def present(
 
     if ctx.get("rerun_data"):
         handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data").get("operation_id"), "compute.firewall"
+            ctx, ctx.get("rerun_data"), "compute.firewall"
         )
 
         if not handle_operation_ret["result"]:
-            result["result"] = False
             result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = ctx.get("rerun_data")
+            if handle_operation_ret.get("rerun_data"):
+                result["rerun_data"] = handle_operation_ret["rerun_data"]
+                if handle_operation_ret["rerun_data"].get("has_error", False):
+                    result["result"] = False
+            else:
+                result["result"] = False
+
             return result
 
         resource_id = handle_operation_ret["resource_id"]
