@@ -377,7 +377,7 @@ async def present(
                 "items",
                 List[
                     make_dataclass(
-                        "Classcc3f9d3b673e4a89805fea2c3069bd85",
+                        "MetadataItemsProperties",
                         [
                             ("key", str, field(default=None)),
                             ("value", str, field(default=None)),
