@@ -148,7 +148,13 @@ async def present(
 
         if not handle_operation_ret["result"]:
             result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
+            if handle_operation_ret.get("rerun_data"):
+                result["rerun_data"] = handle_operation_ret["rerun_data"]
+                if handle_operation_ret["rerun_data"].get("has_error", False):
+                    result["result"] = False
+            else:
+                result["result"] = False
+
             return result
 
         resource_id = handle_operation_ret["resource_id"]
@@ -306,12 +312,18 @@ async def present(
             operation.get("selfLink"), "compute.global_operation"
         )
         handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, operation_id, "compute.network"
+            ctx, {"operation_id": operation_id}, "compute.network"
         )
 
         if not handle_operation_ret["result"]:
             result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
+            if handle_operation_ret.get("rerun_data"):
+                result["rerun_data"] = handle_operation_ret["rerun_data"]
+                if handle_operation_ret["rerun_data"].get("has_error", False):
+                    result["result"] = False
+            else:
+                result["result"] = False
+
             return result
 
         resource_id = handle_operation_ret["resource_id"]
