@@ -125,21 +125,25 @@ async def absent(
     hub,
     ctx,
     name: str = None,
+    project: str = None,
+    zone: str = None,
     resource_id: str = None,
-    request_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Deletes the specified reservation.
+    r"""Deletes the resource.
 
     Args:
-        name(str):
+        name(str, Optional):
             An Idem name of the resource.
 
+        project(str, Optional):
+            Project ID for this request.
+
+        zone(str, Optional):
+            Name of the zone for this request.
+
         resource_id(str, Optional):
             An identifier of the resource in the provider. Defaults to None.
 
-        request_id(str, Optional):
-            An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
-
     Returns:
         Dict[str, Any]
 
@@ -150,64 +154,8 @@ async def absent(
               gcp.compute.reservation.absent:
                 - resource_id: projects/project-name/zones/us-central1-a/reservations/my-reservation
     """
-    result = {
-        "comment": [],
-        "old_state": ctx.get("old_state"),
-        "new_state": None,
-        "name": name,
-        "result": True,
-    }
-
-    if not resource_id:
-        resource_id = (ctx.old_state or {}).get("resource_id")
-
-    if ctx.test:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.would_delete_comment(
-                "gcp.compute.reservation", name
-            )
-        )
-        return result
-
-    if not ctx.get("rerun_data"):
-        # First iteration; invoke reservation's delete()
-        delete_ret = await hub.exec.gcp_api.client.compute.reservation.delete(
-            ctx, resource_id=resource_id
-        )
-        if delete_ret["ret"]:
-            if hub.tool.gcp.operation_utils.is_operation(delete_ret["ret"]):
-                result["result"] = False
-                result["comment"] += delete_ret["comment"]
-                result[
-                    "rerun_data"
-                ] = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                    delete_ret["ret"].get("selfLink"), "compute.zone_operation"
-                )
-                return result
-
-    else:
-        # delete() has been called on some previous iteration
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.reservation"
-        )
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    if not resource_id:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.already_absent_comment(
-                "gcp.compute.reservation", name
-            )
-        )
-
-    result["comment"].append(
-        hub.tool.gcp.comment_utils.delete_comment("gcp.compute.reservation", name)
-    )
-    return result
+    # the method is handled via the recursive_contracts->call_absent
+    raise NotImplementedError
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
