@@ -6,6 +6,8 @@ from typing import Any
 from typing import Dict
 from typing import List
 
+from idem_gcp.tool.gcp.state_operation_utils import StateOperations
+
 __contracts__ = ["resource"]
 
 
@@ -171,30 +173,10 @@ async def present(
 
     project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
-    # Handle operation(s) in progress, if any
-    if ctx.get("rerun_data"):
-        op_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.subnetwork"
+    if ctx.get("wrapper_result"):
+        result["old_state"] = copy.deepcopy(
+            copy.copy(ctx.get("wrapper_result").get("old_state", None))
         )
-
-        if not op_ret["result"]:
-            result["comment"] += op_ret["comment"]
-            result["rerun_data"] = op_ret["rerun_data"]
-            return result
-
-        resource_id = op_ret["resource_id"]
-
-    if resource_id:
-        old = await hub.exec.gcp.compute.subnetwork.get(
-            ctx, name=name, resource_id=resource_id
-        )
-        if not old["result"] or not old["ret"]:
-            result["result"] = False
-            result["comment"] += old["comment"]
-            return result
-
-        result["old_state"] = copy.deepcopy(old["ret"])
-
     request_body = {
         "log_config": log_config,
         "purpose": purpose,
@@ -216,17 +198,34 @@ async def present(
     plan_state = {k: v for (k, v) in plan_state.items() if v is not None}
 
     if result["old_state"]:
+        resource_id = result["old_state"].get("resource_id", None)
         # Update subnetwork
+        patch_operations_dict = {
+            "ip_cidr_range": (
+                hub.tool.gcp.compute.subnetwork.update_ip_cidr_range,
+                (ctx, result["old_state"], ip_cidr_range),
+                True,
+            ),
+        }
+
+        state_operations = StateOperations(
+            hub, "compute.subnetwork", patch_operations_dict, result, request_body
+        )
+
         changes = hub.tool.gcp.utils.compare_states(
             copy.copy(result["old_state"]),
-            {"resource_id": resource_id, **request_body},
+            {
+                "resource_id": resource_id,
+                **request_body,
+                **state_operations.old_properties_dict,
+            },
             "compute.subnetwork",
         )
 
-        if not changes:
+        if not changes and not any(state_operations.changed_properties_dict.values()):
             result["result"] = True
             result["comment"].append(
-                hub.tool.gcp.comment_utils.already_exists_comment(
+                hub.tool.gcp.comment_utils.up_to_date_comment(
                     "gcp.compute.subnetwork", name
                 )
             )
@@ -242,23 +241,63 @@ async def present(
             result["new_state"] = plan_state
             return result
 
-        body = {**request_body, "fingerprint": result["old_state"].get("fingerprint")}
-        body.pop("ip_cidr_range")
-        update = await hub.exec.gcp_api.client.compute.subnetwork.patch(
-            ctx, resource_id=resource_id, body=body
-        )
-        if not update["result"]:
+        state_operations_ret = await state_operations.run_operations()
+
+        if not state_operations_ret["result"]:
+            result["comment"] += state_operations_ret["comment"]
             result["result"] = False
-            result["comment"] += update["comment"]
             return result
 
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.update_comment("gcp.compute.subnetwork", name)
-        )
+        if changes:
+            if any(state_operations.changed_properties_dict.values()):
+                get_ret = await hub.exec.gcp.compute.subnetwork.get(
+                    ctx, name=name, resource_id=resource_id
+                )
 
-        if hub.tool.gcp.operation_utils.is_operation(update["ret"]):
-            operation = update["ret"]
+                if not get_ret["result"] and not get_ret["ret"]:
+                    result["result"] = False
+                    result["comment"] += get_ret["comment"]
+                    return result
 
+                for k in patch_operations_dict.keys():
+                    request_body[k] = get_ret["ret"].get(k)
+
+                request_body["fingerprint"] = get_ret["ret"].get("fingerprint")
+
+            body = (
+                {**request_body, "fingerprint": result["old_state"].get("fingerprint")}
+                if not request_body.get("fingerprint")
+                else {**request_body}
+            )
+            body.pop("ip_cidr_range")
+            state_operations.pre_process_resource_body(body)
+            update = await hub.exec.gcp_api.client.compute.subnetwork.patch(
+                ctx, resource_id=resource_id, body=body
+            )
+            if not update["result"]:
+                result["result"] = False
+                result["comment"] += update["comment"]
+                return result
+
+            if hub.tool.gcp.operation_utils.is_operation(update["ret"]):
+                operation = update["ret"]
+
+        if not changes and any(state_operations.changed_properties_dict.values()):
+            get_ret = await hub.exec.gcp.compute.subnetwork.get(
+                ctx, name=name, resource_id=resource_id
+            )
+            if not get_ret["result"] and not get_ret["ret"]:
+                result["result"] = False
+                result["comment"] += get_ret["comment"]
+                return result
+
+            result["new_state"] = get_ret["ret"]
+            result["comment"].append(
+                hub.tool.gcp.comment_utils.update_comment(
+                    "gcp.compute.subnetwork", name
+                )
+            )
+            return result
     else:
         # Create subnetwork
         if ctx["test"]:
@@ -283,148 +322,37 @@ async def present(
             result["comment"] += create["comment"]
             return result
 
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.create_comment("gcp.compute.subnetwork", name)
-        )
-
         if hub.tool.gcp.operation_utils.is_operation(create["ret"]):
             operation = create["ret"]
 
     if operation:
-        op_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+        operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
             operation.get("selfLink"), "compute.region_operation"
         )
-        op_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, op_id, "compute.subnetwork"
-        )
-
-        if not op_ret["result"]:
-            result["comment"] += op_ret["comment"]
-            result["rerun_data"] = op_ret["rerun_data"]
-            return result
-
-        resource_id = op_ret["resource_id"]
-
-    new = await hub.exec.gcp.compute.subnetwork.get(
-        ctx, name=name, resource_id=resource_id
-    )
-
-    if not new["result"] and not new["ret"]:
-        result["result"] = False
-        result["comment"] += new["comment"]
+        result["rerun_data"] = {
+            "operation_id": operation_id,
+            "old_state": result["old_state"],
+        }
         return result
 
-    result["new_state"] = copy.deepcopy(new["ret"])
-
-    # Update individual properties of the subnetwork, if needed
-
-    prop_updated = False
-
-    if (
-        not ctx["test"]
-        and ip_cidr_range
-        and ip_cidr_range != result["new_state"].get("ip_cidr_range")
-    ):
-        request_body = {"ip_cidr_range": ip_cidr_range}
-
-        ret = await hub.exec.gcp_api.client.compute.subnetwork.expandIpCidrRange(
-            ctx, resource_id=resource_id, body=request_body
-        )
-
-        if not ret["result"] and not ret["ret"]:
-            result["result"] = False
-            result["comment"] += ret["comment"]
-            return result
-
-        if hub.tool.gcp.operation_utils.is_operation(ret["ret"]):
-            operation = ret["ret"]
-
-            operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                operation.get("selfLink"), "compute.region_operation"
-            )
-            handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-                ctx, operation_id, "compute.subnetwork", True
-            )
-
-            if not handle_operation_ret["result"]:
-                result["comment"] += handle_operation_ret["comment"]
-                result["rerun_data"] = handle_operation_ret["rerun_data"]
-                return result
-
-            resource_id = handle_operation_ret["resource_id"]
-            prop_updated = True
-
-    if (
-        not ctx["test"]
-        and private_ip_google_access is not None
-        and private_ip_google_access
-        != result["new_state"].get("private_ip_google_access")
-    ):
-        request_body = {"private_ip_google_access": private_ip_google_access}
-
-        ret = await hub.exec.gcp_api.client.compute.subnetwork.setPrivateIpGoogleAccess(
-            ctx, resource_id=resource_id, body=request_body
-        )
-
-        if not ret["result"] and not ret["ret"]:
-            result["result"] = False
-            result["comment"] += ret["comment"]
-            return result
-
-        if hub.tool.gcp.operation_utils.is_operation(ret["ret"]):
-            operation = ret["ret"]
-
-            operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                operation.get("selfLink"), "compute.region_operation"
-            )
-            handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-                ctx, operation_id, "compute.subnetwork", True
-            )
-
-            if not handle_operation_ret["result"]:
-                result["comment"] += handle_operation_ret["comment"]
-                result["rerun_data"] = handle_operation_ret["rerun_data"]
-                return result
-
-            resource_id = handle_operation_ret["resource_id"]
-            prop_updated = True
-
-    if prop_updated:
-        new = await hub.exec.gcp.compute.subnetwork.get(
-            ctx, name=name, resource_id=resource_id
-        )
-
-        if not new["result"] and not new["ret"]:
-            result["result"] = False
-            result["comment"] += new["comment"]
-            return result
-
-        result["new_state"] = copy.deepcopy(new["ret"])
-
-    return result
-
 
 async def absent(
     hub,
     ctx,
-    name: str,
-    region: str = None,
+    name: str = None,
     project: str = None,
-    request_id: str = None,
     resource_id: str = None,
+    request_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Deletes the specified subnetwork.
+    r"""Deletes the resource.
 
     Args:
-        name(str):
+        name(str, Optional):
             An Idem name of the resource.
 
         project(str, Optional):
             Project ID for this request.
 
-        region(str):
-            Name of the region scoping this request.
-
         request_id(str, Optional):
             An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
 
@@ -433,97 +361,9 @@ async def absent(
 
     Returns:
         Dict[str, Any]
-
-    Examples:
-        .. code-block:: sls
-
-            resource_is_absent:
-              gcp.compute.subnetwork.absent:
-                - name: value
-                - project: value
-                - region: value
     """
-
-    result = {
-        "comment": [],
-        "old_state": ctx.get("old_state"),
-        "new_state": None,
-        "name": name,
-        "result": True,
-    }
-
-    if not resource_id:
-        resource_id = (ctx.old_state or {}).get("resource_id")
-
-    if not resource_id:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.already_absent_comment(
-                "gcp.compute.subnetwork", name
-            )
-        )
-        return result
-
-    if ctx.test:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.would_delete_comment(
-                "gcp.compute.subnetwork", name
-            )
-        )
-        return result
-
-    if not ctx.get("rerun_data"):
-        # First iteration; invoke subnetwork's delete()
-        old = await hub.exec.gcp.compute.subnetwork.get(ctx, resource_id=resource_id)
-        if not old["result"]:
-            result["result"] = False
-            result["comment"] += old["comment"]
-            return result
-        if not old["ret"]:
-            result["comment"].append(
-                hub.tool.gcp.comment_utils.already_absent_comment(
-                    "gcp.compute.subnetwork", name
-                )
-            )
-            return result
-        elif ctx.test:
-            result["old_state"] = copy.deepcopy(old["ret"])
-            result["comment"].append(
-                hub.tool.gcp.comment_utils.would_delete_comment(
-                    "gcp.compute.subnetwork", name
-                )
-            )
-            return result
-        else:
-            result["old_state"] = copy.deepcopy(old["ret"])
-            delete = await hub.exec.gcp_api.client.compute.subnetwork.delete(
-                ctx, resource_id=resource_id
-            )
-            if delete["ret"]:
-                if hub.tool.gcp.operation_utils.is_operation(delete["ret"]):
-                    result["result"] = False
-                    result["comment"] += delete["comment"]
-                    result[
-                        "rerun_data"
-                    ] = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                        delete["ret"].get("selfLink"), "compute.region_operation"
-                    )
-                    return result
-    else:
-        # delete() has been called on some previous iteration
-        op_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.subnetwork"
-        )
-        if not op_ret["result"]:
-            result["comment"] += op_ret["comment"]
-            result["rerun_data"] = op_ret["rerun_data"]
-            return result
-
-        resource_id = op_ret["resource_id"]
-
-    result["comment"].append(
-        hub.tool.gcp.comment_utils.delete_comment("gcp.compute.subnetwork", name)
-    )
-    return result
+    # the method is handled via the recursive_contracts->call_absent
+    raise NotImplementedError
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
