@@ -8,6 +8,8 @@ LIST_RESOURCES_WITH_PRESENT_WRAPPER = [
     "gcp.compute.reservation",
     "gcp.compute.backend_service",
     "gcp.compute.machine_image",
+    "gcp.compute.image",
+    "gcp.compute.instance_group",
 ]
 
 LIST_RESOURCES_WITH_ABSENT_WRAPPER = [
@@ -24,6 +26,7 @@ LIST_RESOURCES_WITH_ABSENT_WRAPPER = [
     "gcp.compute.resource_policy",
     "gcp.compute.snapshot",
     "gcp.compute.subnetwork",
+    "gcp.compute.instance_group",
 ]
 
 
@@ -72,17 +75,19 @@ async def call_present(hub, ctx):
     if state_ctx.get("rerun_data"):
         handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
             state_ctx,
-            state_ctx.get("rerun_data").get("operation_id"),
+            state_ctx.get("rerun_data"),
             service_resource_type,
         )
 
         if not handle_operation_ret["result"]:
             result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = (
-                state_ctx.get("rerun_data")
-                if handle_operation_ret.get("rerun_data")
-                else None
-            )
+            if handle_operation_ret.get("rerun_data"):
+                result["rerun_data"] = handle_operation_ret["rerun_data"]
+                if handle_operation_ret["rerun_data"].get("has_error", False):
+                    result["result"] = False
+            else:
+                result["result"] = False
+
             return result
 
         resource_id = handle_operation_ret["resource_id"]
@@ -198,9 +203,13 @@ async def call_absent(hub, ctx):
 
         get_ret = await hub_ref_exec.get(state_ctx, resource_id=resource_id)
 
-        if not get_ret["result"] or not get_ret["ret"]:
-            result["result"] = True
+        if not get_ret["result"]:
+            result["result"] = False
             result["comment"] += get_ret["comment"]
+            return result
+
+        if not get_ret["ret"]:
+            result["result"] = True
             result["comment"].append(
                 hub.tool.gcp.comment_utils.already_absent_comment(
                     gcp_service_resource_type, name
@@ -261,8 +270,11 @@ async def call_absent(hub, ctx):
             result["comment"] += handle_operation_ret["comment"]
             if handle_operation_ret.get("rerun_data"):
                 result["rerun_data"] = handle_operation_ret["rerun_data"]
+                if handle_operation_ret["rerun_data"].get("has_error", False):
+                    result["result"] = False
             else:
                 result["result"] = False
+
             return result
 
         result["comment"].append(
